Skip to contents

Basic font with no lowercase. Readability is poor, but this produces the most compact text possible.

Use this with render.text().

Usage

fonts.3x3

Format

A font; a list containing font-related properties and a list of sprites for each character.

Details

See also