Resume Live Gameloop
ram.resume.RdThe RAM needs several things to be set every time the gameloop starts:
RAM$timeneeds to be set to the currenttime.sec()for the gameloop's timing to work properly (seevignette("timing")).RAM$beganshould be set toc(time.sec(), RAM$ticks)for inputs to be converted to the correct frame for processing (in inputs.get; see alsovignette("inputs"))
Arguments
- RAM
RAM object.
- start_at
Optional parameter to set the exact
time.sec()when the RAM should start the gameloop; may be useful for syncing online play.