Draw the RAM
render.ram.RdDraws RAM at the current tick by drawing each object in RAM$objects that has a sprite.
Arguments
- RAM
RAM object to draw.
- clear_console
Should the console be wiped before rendering the scene? This keeps the render in a consistent position.
Details
This creates a scene object with size (RAM$ROM$screen.width, RAM$ROM$screen.height),
calls render.object() on every object to draw them onto this scene,
and then calls render.scene().
Examples
RAM = ram.init(R2Studio)
#> Error in RStudio.Version(): could not find function "RStudio.Version"
render.ram(RAM)
#> Error: object 'RAM' not found
#always zoom out with `cmd -` if the render doesn't display properly