Test a Font
render.test_font.RdPrints a large sampler of text using a font to see how it looks in different contexts. You may have to zoom out with cmd - to see the text render properly.
Alternatively, you can test fonts with something like render.matrix(render.text('example_text', font_to_test)).
Arguments
- font
Font to test.
- verbose
Boolean; print extra text samples?
- plaintext
Boolean; print as characters instead?
Details
Uses render.text() to print the following:
lowercase pangram
uppercase pangram
code sample
all symbols
all numbers
lowercase alphabet
uppercase alphabet
The alphabets are drawn last so they show up closest to the bottom of the console. Each of the things printed are useful for different purposes. If the font does not support some characters, the samples containing them will be omitted. (e.g. uppercase-only fonts skip the lowercase samples).
Examples
render.test_font(fonts.3x5)
#>
#> [] [] [] [] [] [][] [] []
#> [][][] [] [][] [][] [] [] [] [][] [][] []
#> [] [][] [][] [][] [] [] [] [][] [] [] [][] [][][] [] [] [] [][] [] [] [] [] [] [] [] [][][] [][] [][] [][]
#> [] [] [] [] [] [] [] [] [] [][] [] [] [] [] [] [][][] [] [] [][] [] [] [] [] [] [] [][][] [] [] [] []
#> [] [] [] [] [][] [][] [][] [][] [] [] [][] [] [] [] [] [] [] [] [] [] [] [][] [][] [] [] [] [] [][]
#>
#>
#> [] [] []
#> [][] [][][] [] [][] [][] [][] [] [] [] [][]
#> [] [] [] [][] [][][] [] [][] [][] [] [][] [] [][] [][] [] [][]
#> [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] []
#> [] [] [] [] [] [] [] [] [] [][] [][] [][] [][] [] [][]
#>
#>
#> [][][] [] [] [][][] [] [] [] [][][] [][] [] [] [][] [][] [][][] [] [] [] [][][] [][][] [] [] [][][] [] [] [] [] [][] [][][] [][]
#> [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [][][] [] [] [] [] []
#> [] [][][] [][] [] [] [] [] [] [] [][] [][] [][] [] [] [][][] [][][] [][] [] [] [] [] [] [] [] [][][] [][] [][] [] []
#> [] [] [] [] [][][] [] [] [] [] [] [] [] [] [] [] [] [] [][][] [][][] [] [] [] [] [] [] [] [] [] [] [] [] [] [] []
#> [] [] [] [][][] [][] [][][] [][][] [][] [] [] [][] [] [] [][][] [] [] [] [] [] [][][] [] [] [] [][][] [] [] [] [][][] [][]
#>
#>
#> [][][] [] [] [][][] [][] [][][] [] [] [][][] [] [] [][][] [] [] [][] [][][] [][]
#> [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] []
#> [] [] [] [] [][] [][] [] [][][] [][] [] [] [] [] [] [] [] [] [] []
#> [] [] [] [] [] [] [] [] [] [] [] [] [][][] [] [] [] [] [] [] [] []
#> [][][] [] [][][] [] [] [] [] [] [][][] [][][] [] [] [][][] [] [][] [][][] [][]
#>
#>
#> [][] [] [] [] [][][] [] [] [] [] [] [] [] [] []
#> [] [] [] [] [] [][] [] [][] [] [] [] [] []
#> [] [] [][][] [] [] [] [][] [][] [] [] [] [] [] [] [] [] [] [][]
#> [][] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] []
#> [] [] [] [] [][] [][] [] [] [][] [] [][][] [] [][][] [] [] [] []
#>
#>
#> [] [] [] [] [] [] [] [] [] [] [] [] []
#> [][] [][][] [] [] [] [] [] [][] [][] [][] [] [] [][] [] [] [] [] []
#> [][] [][][] [] [][] [] [] [][][] [][] [] [] [] [][][] [] [][][] [] [][] []
#> [] [] [] [] [] [] [] [] [] [] [] [] [] [] [][][] [] [] [] [] [] [] [] []
#> [] [] [][] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [][] [] [] []
#>
#>
#> [] [] [] [] []
#> [] [][][] [][] [][][] []
#> [][] [] [] [][] [] [][][] [][][] [][] [][] [] []
#> [] [][][] [] [] [] [][][] [][][] [] [] [] []
#> [] [] [] [][] [] [] [] [] [] [] [] [] [] []
#>
#>
#> [] [] [][] [][] [] [] [] [] [] [] [] [] [] [] [] [] [][] [][][] [] [] [] [] [] [] [] [] []
#> [] [] [] [] [] [] [] [] [] [] [] [][][] [] [] [] [] [] [] [] [] [] [][][] [][][] [][] [] [] [] [] [] [] []
#> [] [] [] [] [][] [][] [] [] [][][] [][][] [] [] [] [][][] [] [] [][][] [] [] [][] [] [] [] []
#> [] [] [] [] [] [] [] [] [] [] [][][] [] [] [] [][][] [][][] [][] [] [][] [] []
#> [] [] [][] [][] [] [] [] [] [] [] [] [] [] [] [] [][][] [] [] [][] [] [] [][][] [][][] [] []
#>
#> [] [] [][] [][] [] [] [][][] [][] [][][] [][][] [][]
#> [] [] [][] [] [] [] [] [] [] [] [] [] [] [] []
#> [] [] [] [] [] [][][] [][] [][] [] [] [][]
#> [] [] [] [] [] [] [] [] [] [] [] [] []
#> [] [][][] [][][] [][] [] [][] [] [] [][][] []
#>
#> [] [] [][] [] [] [] [] []
#> [] [] [][] [] [][] [] [] [][] [][] [][] [] [][][] [] [] [][]
#> [][] [][] [][] [][] [][] [] [][] [][] [] [] [] [] [] [][][] [][] [] [][] [][] [][][] [] [] [] [] [] [] [] [] [] [] [][] []
#> [] [] [] [] [] [] [] [] [][] [] [] [] [] [] [][] [] [][][] [] [] [] [] [] [] [] [] [] [] [] [] [] [][][] [] [] []
#> [][] [][] [][] [][] [] [] [][] [] [] [][] [][] [] [] [] [] [] [] [] [] [] [][] [] [] [] [][] [] [] [] [] [] [][] [][]
#>
#> [] [][] [][] [][] [][][] [][][] [][] [] [] [][][] [][][] [] [] [] [] [] [] [][][] [][] [] [][] [][] [][][] [] [] [] [] [] [] [] [] [] [] [][][]
#> [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [][][] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] []
#> [] [] [][] [] [] [] [][] [][] [] [][][] [] [] [] [][] [] [][][] [][][] [] [] [][] [] [] [][] [] [] [] [] [] [] [][][] [] [] []
#> [][][] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [] [][][] [] [] [] [][][] [] [] [] [] [] [] [] [] [][][] [] [] [] []
#> [] [] [][] [][] [][] [][][] [] [][] [] [] [][][] [] [] [] [][][] [] [] [] [] [][][] [] [][] [] [] [][] [] [][][] [] [] [] [] [] [] [][][]
#zoom out with `cmd -` if needed
#all example text:
render.test_font(NULL,plaintext=TRUE)
#> the quick brown fox jumped over the lazy dog
#> THE QUICK BROWN FOX JUMPED OVER THE LAZY DOG
#> Five Capital Letters Hopped Briskly
#> Yes, too much... Punct-uation! It wasn't 3 o'clock yet; it was 2:30.
#> for (i in 5 * (1:10)){
#> print("Hello World.");
#> } #comment!
#> ()[]{}<>+-*/=~.,:;'"`!?@#$%^&_|\
#> 0123456789
#> abcdefghijklmnopqrstuvwxyz
#> ABCDEFGHIJKLMNOPQRSTUVWXYZ
#> NULL